import sys
import os


def modify_cmake_lists(subdirs):
    # Ensure CMakeLists.txt exists
    cmake_file = 'CMakeLists.txt'
    if not os.path.isfile(cmake_file):
        print(f"{cmake_file} not found!")
        return False

    # Read the contents of CMakeLists.txt
    with open(cmake_file, 'r') as file:
        lines = file.readlines()

    # Remove all add_subdirectory lines and keep other lines
    comment_line_number = next(
        (i for i, line in enumerate(lines) if "# Add all modules" in line), -1
    )
    if comment_line_number != -1:
        # Remove all 'add_subdirectory' lines after the comment
        new_lines = lines[: comment_line_number + 1]

    # Add the desired subdirectory lines at the end
    for subdir in subdirs:
        new_lines.append(f"add_subdirectory({subdir})\n")

    # Write the modified content back to CMakeLists.txt
    with open(cmake_file, 'w') as file:
        file.writelines(new_lines)

    print(f"CMakeLists.txt updated to include: {', '.join(subdirs)}")
    return True

if __name__ == "__main__":
    if len(sys.argv) < 2:
        print("Usage: python modify_cmakelists.py <subdirectory1> <subdirectory2> ...")
        sys.exit(1)

    subdirs = sys.argv[1:]

    if modify_cmake_lists(subdirs):
        sys.exit(0)
    else:
        sys.exit(1)
