""" imports for python """
import sys
import os
import xml.etree.ElementTree as ET
from pathlib import Path
import argparse


def _edit_designEvaluator_xml_file(aircraft_name, aircraft_version_name):
    """_edit_xml_file enables to edit the xml file for the design evaluator.

    :param aircraft_name:         input string
    :param aircraft_version_name: input string
    :return: tree
    """
    tree = ET.parse("design_evaluator_conf.xml")

    elem = tree.find("program_settings/aircraft_design[@ID='1']/file_name")
    elem.text = f"{aircraft_version_name}.xml"

    elem = tree.find("program_settings/aircraft_design[@ID='1']/design_directory")
    elem.text = f"../projects/{aircraft_name}/{aircraft_version_name}_post/"

    elem = tree.find("program_settings/aircraft_design[@ID='0']/file_name")
    elem.text = f"{aircraft_version_name}.xml"

    elem = tree.find("program_settings/aircraft_design[@ID='0']/design_directory")
    elem.text = f"../projects/{aircraft_name}/{aircraft_version_name}_pre/"

    return tree


def rename_config_design_evaluator(aircraft_name: str, aircraft_version_name: str):
    """rename_config_design_evaluator enables to rename the config file of the designEvaluator.

    The input "aircraft_name" contains the aircraft name set in the config file (e.g. CSR).

    :param aircraft_name:         input string
    :param aircraft_version_name: input string
    :return: none
    """

    edited_xml_content = _edit_designEvaluator_xml_file(
        aircraft_name, aircraft_version_name
    )

    edited_xml_content.write("design_evaluator_conf.xml")

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="A simple example script.")
    parser.add_argument('--type', type=str, help='Type of the aircraft, e.g. CSR')
    parser.add_argument('--version', type=str, help='Version of the aircraft, e.g. CSR-02')

    args = parser.parse_args()

    rename_config_design_evaluator(args.type, args.version)
